import { Construct, NestedStack } from '@aws-cdk/core';
import { GraphqlApi, FieldLogLevel, AuthorizationConfig } from '@aws-cdk/aws-appsync';
/**
 * Properties for AppSyncTransformer Construct
 * @param schemaPath Relative path where schema.graphql exists.
 * @param authorizationConfig {@link AuthorizationConfig} type defining authorization for AppSync GraphqlApi. Defaults to API_KEY
 * @param apiName Optional string value representing the api name
 * @param syncEnabled Optional boolean to enable DataStore Sync Tables
 * @param fieldLogLevel {@link FieldLogLevel} type for AppSync GraphqlApi log level
 */
export interface AppSyncTransformerProps {
    /**
     * Required. Relative path where schema.graphql exists
     */
    readonly schemaPath: string;
    /**
     * Optional. {@link AuthorizationConfig} type defining authorization for AppSync GraphqlApi. Defaults to API_KEY
     * @default API_KEY authorization config
     */
    readonly authorizationConfig?: AuthorizationConfig;
    /**
     * Optional. String value representing the api name
     * @default `${id}-api`
     */
    readonly apiName?: string;
    /**
     * Optional. Boolean to enable DataStore Sync Tables
     * @default false
     */
    readonly syncEnabled?: boolean;
    /**
     * Optional. {@link FieldLogLevel} type for AppSync GraphqlApi log level
     * @default FieldLogLevel.NONE
     */
    readonly fieldLogLevel?: FieldLogLevel;
}
/**
 * AppSyncTransformer Construct
 */
export declare class AppSyncTransformer extends Construct {
    readonly appsyncAPI: GraphqlApi;
    readonly nestedAppsyncStack: NestedStack;
    readonly tableNameMap: any;
    readonly outputs: any;
    readonly resolvers: any;
    private isSyncEnabled;
    private syncTable;
    constructor(scope: Construct, id: string, props: AppSyncTransformerProps);
    private createNoneDataSourceAndResolvers;
    private createTablesAndResolvers;
    private createTable;
    private createSyncTable;
    private convertAttributeType;
    private convertProjectionType;
    private getTableNameFromFieldName;
}
